[LON-CAPA-cvs] cvs: loncom /xml lonplot.pm

matthew lon-capa-cvs@mail.lon-capa.org
Wed, 27 Feb 2002 16:54:58 -0000


matthew		Wed Feb 27 11:54:58 2002 EDT

  Modified files:              
    /loncom/xml	lonplot.pm 
  Log:
  Corrected idiot error - inserting plots will now actually have the correct tags.
  
  
Index: loncom/xml/lonplot.pm
diff -u loncom/xml/lonplot.pm:1.49 loncom/xml/lonplot.pm:1.50
--- loncom/xml/lonplot.pm:1.49	Wed Feb  6 05:33:27 2002
+++ loncom/xml/lonplot.pm	Wed Feb 27 11:54:58 2002
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Dynamic plot
 #
-# $Id: lonplot.pm,v 1.49 2002/02/06 10:33:27 matthew Exp $
+# $Id: lonplot.pm,v 1.50 2002/02/27 16:54:58 matthew Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1089,7 +1089,7 @@
 sub insert_gnuplot {
     my $result = '';
     #  plot attributes
-    $result .= "<plot \n";
+    $result .= "<gnuplot \n";
     foreach my $attr (keys(%gnuplot_defaults)) {
 	$result .= "     $attr=\"$gnuplot_defaults{$attr}->{'default'}\"\n";
     }
@@ -1101,8 +1101,8 @@
     # $result .= &insert_xlabel();    
     # $result .= &insert_ylabel();    
     $result .= &insert_curve();
-    # close up the <plot>
-    $result .= "</plot>\n";
+    # close up the <gnuplot>
+    $result .= "</gnuplot>\n";
     return $result;
 }